--- /home/cpdev/src/classpath/gnu/java/lang/CharData.java	2005-07-02 21:03:03.000000000 +0000
+++ gnu/java/lang/CharData.java	2005-06-30 05:34:05.000000000 +0000
@@ -41,9 +41,9 @@
 /**
  * This contains the info about the unicode characters, that
  * java.lang.Character needs.  It is generated automatically from
  * <code>doc/unicode/UnicodeData-3.0.0.txt</code> and
  * <code>doc/unicode/SpecialCasing-2.txt</code>, by some
  * perl scripts. These Unicode definition file can be found on the
  * <a href="http://www.unicode.org">http://www.unicode.org</a> website.
  * JDK 1.4 uses Unicode version 3.0.0.
  *
@@ -73,7 +73,7 @@
   /**
    * The Unicode definition file that was parsed to build this database.
    */
-  String SOURCE = "doc/unicode/UnicodeData-3.0.0.txt";
+  String SOURCE = "gnu/gcj/convert/UnicodeData-3.0.0.txt";
 
   /**
    * The character shift amount to look up the block offset. In other words,
@@ -41,9 +41,9 @@
  * This contains the info about the unicode characters, that
  * java.lang.Character needs.  It is generated automatically from
- * <code>doc/unicode/UnicodeData-3.0.0.txt</code> and
- * <code>doc/unicode/SpecialCasing-2.txt</code>, by some
- * perl scripts. These Unicode definition file can be found on the
+ * <code>gnu/gcj/convert/UnicodeData-3.0.0.txt</code> and
+ * <code>gnu/gcj/convert/SpecialCasing-2.txt</code>, by some
+ * perl scripts. These Unicode definition files can be found on the
  * <a href="http://www.unicode.org">http://www.unicode.org</a> website.
  * JDK 1.4 uses Unicode version 3.0.0.
